<?php
/**
 * D5 Business Line Pro Options Page
 * @ Copyright: D5 Creation, All Rights, www.d5creation.com
 */

function optionsframework_option_name() {

	// This gets the theme name from the stylesheet
	$themename = 'd5businesslinepro';
	$optionsframework_settings = get_option( 'optionsframework' );
	$optionsframework_settings['id'] = $themename;
	update_option( 'optionsframework', $optionsframework_settings );
}

/**
 * Defines an array of options that will be used to generate the settings page and be saved in the database.
 * When creating the 'id' fields, make sure to use all lowercase and no spaces.
 *
 * If you are making your theme translatable, you should replace 'd5businesslinepro'
 * with the actual text domain for your theme.  Read more:
 * http://codex.wordpress.org/Function_Reference/load_theme_textdomain
 */

function optionsframework_options() {
	
	// add_filter( 'wp_default_editor', create_function('', 'return "html";') ); 
	
	$wp_editor_settings = array(
		'wpautop' => false, // Default
		'textarea_rows' => 5,
		'editor_css' => '<style>.wp-editor-tools, .quicktags-toolbar { visibility: hidden; display: none; height:0px;} </style>',
		'teeny' => true,
'tinymce' => false,
'quicktags' => false
	);	
	
	$options[] = array(
		'name' => 'General Options', 
		'type' => 'heading');
	
	$options[] = array(
		'name' => 'Site Favicon', 
		'desc' => 'Upload an Icon for the Site Favicon. 16px X 16px image is recommended.', 
		'id' => 'favicon',
		'std' => get_template_directory_uri() . '/images/favicon.ico',
		'type' => 'upload');	

	$options[] = array(
		'name' => 'Company Logo', 
		'desc' => 'Upload an image for the Company Logo. 300px X 90px image is recommended.', 
		'id' => 'site-logo',
		'std' => get_template_directory_uri() . '/images/logo.png',
		'type' => 'upload');	
		
	$options[] = array(
		'name' => 'Show Site Logo in Login Page', 
		'desc' => 'Check it if you want to show Site Logo in Login Page', 
		'id' => 'login-logo',
		'std' => '1',
		'type' => 'checkbox' );	
		
	// Background Defaults
	$header_background_defaults = array(
		'color' => '#26292B',
		'image' => get_template_directory_uri() . '/images/header.png',
		'repeat' => 'repeat',
		'position' => '0 0',
		'attachment'=>'scroll' );
		
	$options[] = array(
		'name' => 'Set Header Background', 
		'desc' => 'You can set the WebSite Header here. Defaults: Color - #F6F6F6, Image - '. get_template_directory_uri() . '/images/background.png' ,
		'id' => 'website-back',
		'std' => $header_background_defaults,
		'type' => 'background' );
		
	$options[] = array(
		'name' => 'Front Page Heading', 
		'desc' => 'Input your heading text here. Plese limit it within 100 Letters.', 
		'id' => 'heading_text',
		'std' => 'World class and industry standard IT services are our passion. We build your ideas True',
		'type' => 'text');
	
// Quotation	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Bottom Quotation</span>', 
		'type' => 'info');
	
	$options[] = array(
		'name' => 'Quote Text', 
		'desc' => 'Input your Quotation here. Plese limit it within 150 Letters.', 
		'id' => 'bottom-quotation',
		'std' => 'All the developers of D5 Creation have come from the disadvantaged part or group of the society. All have established themselves after a long and hard struggle in their life ----- D5 Creation Team',
		'type' => 'textarea');

	$options[] = array(
		'name' => 'Custom Code within Head Area', 
		'desc' => 'You can input any Custom Code Here like Google Analytics Code, CSS, Java Script etc.', 
		'id' => 'headcode',
		'std' => '',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
		
	$fw_column = array(
		'fw-oneclm' => 'One Column', 
		'fw-twoclm' => 'Two Column', 
		'fw-threeclm' => 'Three Column', 
		'fw-fourclm' => 'Four Column', 
	);
	
	$options[] = array(
		'name' => 'Select Number of Column for Footer Widget', 
		'desc' => 'Select Number of Footer Widget Columns', 
		'id' => 'fw_clm',
		'std' => 'fw-fourclm',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $fw_column);
		
	$options[] = array(
		'name' => 'Copyright Notice',
		'desc' => 'You can input your copyright notice or other links like sitemap here.',
		'id' => 'copyright',
		'std' => '&copy; ' . date('Y'). ': ' . get_bloginfo( 'name' ) . ', All Rights Reserved',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => 'Author and WordPress Credit', 
		'desc' => 'Hide Author and CMS Creadit from Footer', 
		'id' => 'credit',
		'std' => '0',
		'type' => 'checkbox' );	
		
	$contype = array( '1' => 'Full Content in Blog Page. Also Support Read More Button if inserted during Editing.', '2' => 'Some Words and Read More Button in the Blog Page' );
	
	$options[] = array(
		'name' => 'Select the Content Type in the Blog Page.',
		'desc' => 'Select whether you want to show the Full / Selected Content or Some Words and Read More Button Automatically.', 
		'id' => 'contype',
		'std' => '1',
		'type' => 'radio',
		'options' => $contype);
		
	$options[] = array(
		'name' => 'Page Comments Box',
		'desc' => 'Hide WordPress Comments Box from All Pages',
		'id' => 'cpage',
		'std' => '0',
		'type' => 'checkbox' );	
		
	$options[] = array(
		'name' => 'Blog Post Comments Box',
		'desc' => 'Hide WordPress Comments Box from All Posts',
		'id' => 'cpost',
		'std' => '0',
		'type' => 'checkbox' );	
		
	$options[] = array(
		'name' => 'Hide Admin Bar',
		'desc' => 'Hide WordPress Admin Bar for Logged In Users',
		'id' => 'admin-bar',
		'std' => '0',
		'type' => 'checkbox' );
		
	$options[] = array(
		'name' => "Site Layout",
		'desc' => "You can set the Site Layout for Whole the Site.",
		'id' => "site-layout",
		'std' => "2c-r-fixed",
		'type' => "images",
		'options' => array(
			'1col-fixed' => get_template_directory_uri() . '/images/1col.png',
			'2c-l-fixed' => get_template_directory_uri() . '/images/2cl.png',
			'2c-r-fixed' => get_template_directory_uri() . '/images/2cr.png')
	);	
		
	$options[] = array(
		'name' => 'Full Width Layout for WooCommerce Pages',
		'desc' => 'Check it if you want to show Full Width Layout for WooCommerce Pages', 
		'id' => 'woo-page-full',
		'std' => '1',
		'type' => 'checkbox' );	
		
	$options[] = array(
		'name' => 'Use Responsive Layout', 
		'desc' => 'Check the Box if you want the Responsive Layout of your Website', 
		'id' => 'responsive',
		'std' => '0',
		'type' => 'checkbox');
		
	$options[] = array(
		'name' => 'Hide Author and Date from Posts',
		'desc' => 'Hide Author and Date from Posts',
		'id' => 'wpad',
		'std' => '0',
		'type' => 'checkbox' );	
		
	$options[] = array(
		'name' => 'Hide Posted in, Comments Off, Tag etc. from Posts',
		'desc' => 'Hide Posted in, Comments Off, Tag etc. from Posts',
		'id' => 'wppct',
		'std' => '0',
		'type' => 'checkbox' );	
		
	$fposttype = array( '1' => 'Do nor Show any Post or Page in the Front Page.', '2' => 'Show Posts or Page and Left/Right Sidebar.', '3' => 'Show Posts or Page Full Width without Left/Right Sidebar.' );
	
	$options[] = array(
		'name' => 'Front Page Post/Page Visibility', 
		'desc' => 'Select Option how you want to show or do not want to show Posts/Pages in the Front Page', 
		'id' => 'fpostex',
		'std' => '1',
		'type' => 'radio',
		'options' => $fposttype);
		

// Front Page Fearured Boxs
	$fbox_column = array(
		'fbox-oneclm' => 'One Column', 
		'fbox-twoclm' => 'Two Column', 
		'fbox-threeclm' => 'Three Column', 
		'fbox-fourclm' => 'Four Column', 
	);
	
	$options[] = array(
		'name' => 'Featured Boxs', 
		'type' => 'heading');
		
	$options[] = array(
		'name' => 'Select Number of Column for Featured Box', 
		'desc' => 'Select Front Page Number of Featured Box Columns ', 
		'id' => 'fbox_clm',
		'std' => 'fbox-fourclm',
		'type' => 'select',
		'class' => 'mini', //mini, tiny, small
		'options' => $fbox_column);
	
	
	$options[] = array(
		'name' => 'Number of Featured Boxes', 
		'desc' => 'Set the Number of Featured Boxes you want.', 
		'id' => 'nfbox1',
		'std' => '4',
		'type' => 'text',
		'class' => 'mini');
		
	$numfbox2 = of_get_option('nfbox1', '4');
	foreach (range(1, $numfbox2 ) as $fbsinumber ) {
	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Featured Box: ' . $fbsinumber . '</span>',
		'type' => 'info');
	
	$options[] = array(
		'name' => 'Featured Image', 
		'desc' => 'Upload an image for the Featured Box. 215px X 100px image is recommended for 04 Column and for 01, 02 or 03 Column maintain the same ratio. If you do not want to show anything here leave the box blank.', 
		'id' => 'featured-image' . $fbsinumber,
		'std' => get_template_directory_uri() . '/images/featured-image' . $fbsinumber . '.jpg',
		'type' => 'upload');	
	
	$options[] = array(
		'name' => 'Featured Title', 
		'desc' => 'Input your Featured Title here. Plese limit it within 30 Letters. If you do not want to show anything here leave the box blank.', 
		'id' => 'featured-title' . $fbsinumber,
		'std' => 'D5 Business Line Theme for Small Business',
		'type' => 'text');
	
	$options[] = array(
		'name' => 'Featured Description', 
		'desc' => 'Input the description of Featured Areas. Please limit the words within 30 so that the layout should be clean and attractive. You can also input any HTML, Videos or iframe here. But Please keep in mind about the limitation of Width of the box.', 
		'id' => 'featured-description' . $fbsinumber,
		'std' => 'The Customizable Background and other options of D5 Business Line will give the WordPress Driven Site an attractive look.  D5 Business Line is super elegant and Professional Responsive Theme which will create the business widely expressed.',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	$options[] = array(
		'name' => 'Featured Link', 
		'desc' => 'Input your Featured Items URL here.', 
		'id' => 'featured-link' . $fbsinumber,
		'std' => '#',
		'type' => 'text');

	}
	
	// Front Page Client List
	$options[] = array(
		'name' => 'Clients', 
		'type' => 'heading');
	
		
	$options[] = array(
		'desc' => '<strong>Check This if You want to Show Your Cients List</strong>', 
		'id' => 'client-visibility',
		'std' => '1',
		'type' => 'checkbox' );	
		
	$options[] = array(
		'desc' => '<span class="featured-area-title">Clients or Partners List</span>', 
		'type' => 'info'); 
		
	$options[] = array(
		'name' => 'Client Text', 
		'desc' => 'Input your Featured Items URL here.', 
		'id' => 'client-text',
		'std' => 'Some of our Proud Partners',
		'type' => 'text');	
	
	$csin=array('1','2','3','4','5','6','7');
	foreach ($csin as $csinumber) {
		
	
	$options[] = array(
		'name' => 'Client 0'. $csinumber, 
		'desc' => 'Upload a Logo of the Client 120px X 90px PNG image is recommended.', 
		'id' => 'client' . $csinumber,
		'std' => get_template_directory_uri() . '/images/client' . $csinumber . '.png',
		'type' => 'upload');
		
	$options[] = array(
		'name' => 'Client 0'. $csinumber . ' Link ', 
		'desc' => 'Input the URL where the image will redirect the visitors, if Applicable.', 
		'id' => 'client-image' . $csinumber . '-link',
		'std' => '',
		'type' => 'text');	
	}

		
// Slider Settings
	$options[] = array(
		'name' => 'Slider Settings', 
		'type' => 'heading');
	
	$options[] = array(
		'name' => 'Slide Effect', 
		'desc' => 'Select the Slide Effect (01)Zipper, (02)Curtain, (03)Wave',
		'id' => 'slide-effect',
		'std' => 'zipper',
		'type' => 'images',
		'options' => array(
			'zipper' => get_template_directory_uri() . '/images/zipper.png',
			'curtain' => get_template_directory_uri() . '/images/curtain.png',
			'wave' => get_template_directory_uri() . '/images/wave.png',
			'' => get_template_directory_uri() . '/images/none.png')
	);
	
	$options[] = array(
		'name' => 'Slide Position', 
		'desc' => 'Select the Slide Effect Position.  This will only work when you will select the Slide Effect to NONE',
		'id' => 'slide-position',
		'std' => 'alternate',
		'type' => 'radio',
		'options' => array(
			'top' => 'Top',
			'bottom' => 'Bottom',
			'alternate' => 'Alternate',
			'curtain' => 'Curtain',)
	);
	
	$options[] = array(
		'name' => 'Slide Direction', 
		'desc' => 'Select the Slide Effect Direction. This will only work when you will select the Slide Effect to NONE',
		'id' => 'slide-direction',
		'std' => 'fountainAlternate',
		'type' => 'radio',
		'options' => array(
			'left' => 'Left',
			'right' => 'Right',
			'alternate' => 'Alternate',
			'random' => 'Random',
			'fountain' => 'Fountain',
			'fountainAlternate' => 'Fountain Alternate',)
	);
	
	$options[] = array(
		'name' => 'Number of Slides', 
		'desc' => 'Set the Number of Slides. Dafault is 10.', 
		'id' => 'slide-number',
		'std' => '10',
		'type' => 'text',
		'class' => 'mini' ); 
	
	$options[] = array(
		'name' => 'Slide Width and Height', 
		'desc' => 'Set the Slide Width. Default and Maximum value is 1050px.', 
		'id' => 'slide-width',
		'std' => '1050',
		'type' => 'text',
		'class' => 'mini' ); 
		
	$options[] = array(
		'desc' => 'Set the Slide Height. Default and Maximum value is 400px.', 
		'id' => 'slide-height',
		'std' => '400',
		'type' => 'text',
		'class' => 'mini' );
		
	$options[] = array(
		'name' => 'Delay between Images in Milliseconds', 
		'desc' => 'Insert the integer value of Slide Image Duration. Default is 5000.', 
		'id' => 'slide-duration',
		'std' => '5000',
		'type' => 'text',
		'class' => 'mini');
		
	$options[] = array(
		'name' => 'Number of Strips', 
		'desc' => 'Insert the integer value of Slide Image Number of Strips. Default is 19.', 
		'id' => 'slide-strips',
		'std' => '19',
		'type' => 'text',
		'class' => 'mini');
	
	$options[] = array(
		'name' => 'Delay beetwen strips in Milliseconds', 
		'desc' => 'Insert the integer value of Slide Image Delay between strips in Milliseconds. Default is 50.', 
		'id' => 'slide-dstrips',
		'std' => '50',
		'type' => 'text',
		'class' => 'mini');
		
	$options[] = array(
		'name' => 'Image Caption Speed in Milliseconds', 
		'desc' => 'Insert the integer value of Image Caption Speed in Milliseconds. Default is 1000.', 
		'id' => 'slide-cspeed',
		'std' => '1000',
		'type' => 'text',
		'class' => 'mini');
		
	$options[] = array(
		'name' => 'Do not Show Shadow Under Slide',
		'desc' => 'Check it if you do not want any shadow under the Slide', 
		'id' => 'slide-shadow',
		'std' => '0',
		'type' => 'checkbox' );
		
	$options[] = array(
		'name' => 'Slider Container Background',
		'desc' => 'Select the Color for Slider Container Background. This will chnage some style of Slider. Leave blank for transparent Background.', 
		'id' => 'slide-color',
		'std' => '',
		'type' => 'color' );
	
	$opsin = of_get_option('slide-number', '10');
	foreach (range(1, $opsin) as $opsinumber) {
	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Sliding Image - ' . $opsinumber . '</span>', 
		'type' => 'info');
	
	$options[] = array(
		'name' => 'Sliding Image', 
		'desc' => 'Upload an Sliding Image. 1050px X 400px image is recommended. Please upload an optimized image for smooth running of the slides.', 
		'id' => 'slide-image' . $opsinumber,
		'std' => get_template_directory_uri() . '/images/slide-image/slide-image' . $opsinumber . '.jpg',
		'type' => 'upload');
		
	$options[] = array(
		'name' => 'Image Caption / HTML Content', 
		'desc' => 'Input the Caption or HTML Content for the Image.', 
		'id' => 'slide-image' . $opsinumber . '-caption',
		'std' => 'This is a Test Image for D5 Business Line Extend Theme. If you feel any problem please contact with D5 Creation.',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
		
	$options[] = array(
		'name' => 'Image Link', 
		'desc' => 'Input the URL where the image will redirect the visitors.', 
		'id' => 'slide-image' . $opsinumber . '-link',
		'std' => '#',
		'type' => 'text');
	}

// 	Banner Video
	$options[] = array(
		'name' => 'Banner Video', 
		'type' => 'heading');		

	
	$options[] = array(
		'desc' => 'You can insert Video or anything else you want instead of the Sliding Image. But it will disable the Sliding Image. If you enable the Sliding Image again you must remove the contents of the following editor.',
		'type' => 'info');
	
		
	$options[] = array(
		'name' => 'Banner Video or Another Thing', 
		'desc' => 'Input your Content Here. You can inpur the Embaded Code for Videos like You Tube Video or any other HTML, iframe content here. The Content Width must be within 1000px.', 
		'id' => 'banner-video',
		'std' => '',
		'type' => 'editor',
		'settings' => $wp_editor_settings );

	// Social Contacts
	$options[] = array(
		'name' => 'Social Connects', 
		'type' => 'heading');		

	
	$options[] = array(
		'desc' => '<span class="featured-area-title">Social Links</span>', 
		'type' => 'info');
		
		
	$options[] = array(
		'name' => 'Facebook Link', 
		'desc' => 'Input your Facebook URL here.', 
		'id' => 'facebook-link',
		'std' => 'http://facebook.com/d5creation',
		'type' => 'text');

	$options[] = array(
		'name' => 'Twitter Link', 
		'desc' => 'Input your Twitter URL here.', 
		'id' => 'twitter-link',
		'std' => 'http://twitter.com/d5creation',
		'type' => 'text');
	
	$options[] = array(
		'name' => 'You Tube Channel Link', 
		'desc' => 'Input your You Tube Channel URL here.', 
		'id' => 'youtube-link',
		'std' => 'http://www.youtube.com/d5creation',
		'type' => 'text');

	$options[] = array(
		'name' => 'Linked In Link', 
		'desc' => 'Input your Linked In URL here.', 
		'id' => 'li-link',
		'std' => 'http://lnkd.in/waY9_A',
		'type' => 'text');

	$options[] = array(
		'name' => 'Feed or Blog Link', 
		'desc' => 'Input your Feed or Blog URL here.', 
		'id' => 'feed-link',
		'std' => 'http://d5creation.com/news/',
		'type' => 'text');
		
	
	// 	Color Settings
	$options[] = array(
		'name' => 'Color', 
		'type' => 'heading');		

	
	$options[] = array(
		'desc' => 'You can edit the color of your site from here. We recommend you to do any customization here. It is just like CSS. If you are not familiar with CSS you should not touch this.',
		'type' => 'info');
		
	$options[] = array(
		'name' => 'Use This Customized Design', 
		'desc' => 'Check this box if you want to use the following Custom Style Code', 
		'id' => 'colorcssaccept',
		'std' => '0',
		'type' => 'checkbox' );	
	
	$options[] = array(
		'name' => 'Color 01', 
		'desc' => 'Change the Color <b>#FFFFFF</b>', 
		'id' => 'color1',
		'std' => '#FFFFFF',
		'type' => 'color' );
	
	$options[] = array(
		'name' => 'Color 02', 
		'desc' => 'Change the Color <b>#EEEEEE</b>', 
		'id' => 'color2',
		'std' => '#EEEEEE',
		'type' => 'color' );
		
	$options[] = array(
		'name' => 'Color 03', 
		'desc' => 'Change the Color <b>#CCCCCC</b>', 
		'id' => 'color3',
		'std' => '#CCCCCC',
		'type' => 'color' );
		
	$options[] = array(
		'name' => 'Color 04', 
		'desc' => 'Change the Color <b>#999999</b>', 
		'id' => 'color4',
		'std' => '#999999',
		'type' => 'color' );	
		
	$options[] = array(
		'name' => 'Color 05', 
		'desc' => 'Change the Color <b>#555555</b>', 
		'id' => 'color5',
		'std' => '#555555',
		'type' => 'color' );
		
	$options[] = array(
		'name' => 'Color 06', 
		'desc' => 'Change the Color <b>#333333</b>', 
		'id' => 'color6',
		'std' => '#333333',
		'type' => 'color' );	
	
	$options[] = array(
		'name' => 'Color 07', 
		'desc' => 'Change the Color <b>#26292B</b>', 
		'id' => 'color7',
		'std' => '#26292B',
		'type' => 'color' );
		
	$options[] = array(
		'name' => 'Color 08', 
		'desc' => 'Change the Color <b>#111111</b>', 
		'id' => 'color8',
		'std' => '#252525',
		'type' => 'color' );	
		
	$options[] = array(
		'name' => 'Color 09', 
		'desc' => 'Change the Color <b>#0DB0D8</b>', 
		'id' => 'color9',
		'std' => '#0DB0D8',
		'type' => 'color' );
		
	$options[] = array(
		'name' => 'Color 10', 
		'desc' => 'Change the Color <b>#0387BF</b>', 
		'id' => 'color10',
		'std' => '#0387BF',
		'type' => 'color' );		
		
	$options[] = array(
		'name' => 'Color 11', 
		'desc' => 'Change the Color <b>#085D96</b>', 
		'id' => 'color11',
		'std' => '#085D96',
		'type' => 'color' );	
		
	$options[] = array(
		'name' => 'Color 12', 
		'desc' => 'Change the Color <b>#FF3300</b>', 
		'id' => 'color12',
		'std' => '#FF3300',
		'type' => 'color' );
		
	$options[] = array(
		'name' => 'Color CSS of your Site', 
		'desc' => 'You can set your own colors and image locations for your site. You can also pste Custom CSS in the following Box. You need not use starting and closing <b>style</b> tag.', 
		'type' => 'info' );
		
	$options[] = array(
		'id' => 'color-setting',
		'std' => '',
		'type' => 'editor',
		'settings' => $wp_editor_settings );
		
	
		// Language Settings
	$options[] = array(
		'name' => 'Language',
		'type' => 'heading');		
	
	$options[] = array(
		'desc' => 'You can chnage the texts as your own language. These are only the Front End Texts which your visitors will see.',
		'type' => 'info');	
		
	$options[] = array(
		'name' => 'Your Search Text Here',
		'desc' => 'Chnage the Text <b>Your Search Text Here</b>.',
		'id' => 'sth',
		'std' => 'Search Text Here',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Search',
		'desc' => 'Chnage the Text <b>Search</b>.',
		'id' => 'src',
		'std' => 'Search',
		'type' => 'text',
		'class' => 'mini');	
	
	$options[] = array(
		'name' => 'Read More ...',
		'desc' => 'Chnage the Text <b>Read More ...</b>.',
		'id' => 'readmore',
		'std' => 'Read More ...',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Posted by',
		'desc' => 'Chnage the Text <b>Posted by</b>.',
		'id' => 'postedby',
		'std' => 'Posted by',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Posted in',
		'desc' => 'Chnage the Text <b>Posted in</b>.',
		'id' => 'postedin',
		'std' => 'Posted in',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Tags',
		'desc' => 'Chnage the Text <b>Tags</b>.',
		'id' => 'tags',
		'std' => 'Tags',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'No Comments',
		'desc' => 'Chnage the Text <b>No Comments</b>.',
		'id' => 'nocomments',
		'std' => 'No Comments',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Comments',
		'desc' => 'Chnage the Text <b>Comments</b>.',
		'id' => 'comments',
		'std' => 'Comments',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'One Comment',
		'desc' => 'Chnage the Text <b>One Comment</b>.',
		'id' => '1comment',
		'std' => 'One Comment',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Comments are Closed',
		'desc' => 'Chnage the Text <b>Comments are Closed</b>.',
		'id' => 'cac',
		'std' => 'Comments are Closed',
		'type' => 'text');
	
	$options[] = array(
		'name' => 'To',
		'desc' => 'Chnage the Text <b>to</b>.',
		'id' => 'to2',
		'std' => 'to',
		'type' => 'text',
		'class' => 'mini');	

	$options[] = array(
		'name' => 'This post is password protected. Enter the password to view comments.',
		'desc' => 'Chnage the Text <b>This post is password protected. Enter the password to view comments</b>.',
		'id' => 'ppp1',
		'std' => 'This post is password protected. Enter the password to view comments.',
		'type' => 'text');
	
	$options[] = array(
		'name' => 'Previous Image',
		'desc' => 'Chnage the Text <b>Previous Image</b>.',
		'id' => 'pi3',
		'std' => 'Previous Image',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Next Image',
		'desc' => 'Chnage the Text <b>Next Image</b>.',
		'id' => 'ni3',
		'std' => 'Next Image',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Previous Entries',
		'desc' => 'Chnage the Text <b>Pxrevious Entries</b>.',
		'id' => 'pe3',
		'std' => 'Previous Entries',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Next Entries',
		'desc' => 'Chnage the Text <b>Next Entries</b>.',
		'id' => 'ne3',
		'std' => 'Next Entries',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Search Results',
		'desc' => 'Chnage the Text <b>Search Results</b>.',
		'id' => 'srslt',
		'std' => 'Search Results',
		'type' => 'text',
		'class' => 'mini');	

	
	$options[] = array(
		'name' => 'Search Term',
		'desc' => 'Chnage the Text <b>Search Term</b>.',
		'id' => 'strm',
		'std' => 'Search Term',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Number of Results',
		'desc' => 'Chnage the Text <b>Number of Results</b>.',
		'id' => 'nosrc',
		'std' => 'Number of Results',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Entry Date',
		'desc' => 'Chnage the Text <b>Entry Date</b>.',
		'id' => 'edate',
		'std' => 'Entry Date',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Sorry, we could not find anything that matched your search.',
		'desc' => 'Chnage the Text <b>Sorry, we could not find anything that matched your search.</b>.',
		'id' => 'swcf',
		'std' => 'Sorry, we could not find anything that matched your search.',
		'type' => 'text');	
		
	$options[] = array(
		'name' => 'You Can Try Another Search...',
		'desc' => 'Chnage the Text <b>You Can Try Another Search...</b>.',
		'id' => 'yctas',
		'std' => 'You Can Try Another Search...',
		'type' => 'text');	

	$options[] = array(
		'name' => 'Or Return to the Home Page',
		'desc' => 'Chnage the Text <b>Or Return to the Home Page</b>.',
		'id' => 'orhp',
		'std' => 'Or Return to the Home Page',
		'type' => 'text');	
		
	$options[] = array(
		'name' => 'You can also Visit the Following. These are the Featured Contents',
		'desc' => 'Chnage the Text <b>You can also Visit the Following. These are the Featured Contents</b>.',
		'id' => 'ycvffc',
		'std' => 'You can also Visit the Following. These are the Featured Contents',
		'type' => 'text');	
		
	$options[] = array(
		'name' => 'Not Found',
		'desc' => 'Chnage the Text <b>Not Found</b>.',
		'id' => 'notf',
		'std' => 'Not Found',
		'type' => 'text',
		'class' => 'mini');	
		
	$options[] = array(
		'name' => 'Apologies, but the page you requested could not be found. Perhaps searching will help.',
		'desc' => 'Chnage the Text <b>Apologies, but the page you requested could not be found. Perhaps searching will help.</b>.',
		'id' => 'apologies',
		'std' => 'Apologies, but the page you requested could not be found. Perhaps searching will help.',
		'type' => 'text');
		
	$options[] = array(
		'name' => 'now browsing by category',
		'desc' => 'Chnage the Text <b>now browsing by category</b>.',
		'id' => 'arc1',
		'std' => 'now browsing by category',
		'type' => 'text');	
		
	$options[] = array(
		'name' => 'now browsing by tag',
		'desc' => 'Chnage the Text <b>now browsing by tag</b>.',
		'id' => 'arc2',
		'std' => 'now browsing by tag',
		'type' => 'text');
		
	$options[] = array(
		'name' => 'now browsing by day',
		'desc' => 'Chnage the Text <b>now browsing by day</b>.',
		'id' => 'arc3',
		'std' => 'now browsing by day',
		'type' => 'text');	
		
	$options[] = array(
		'name' => 'now browsing by month',
		'desc' => 'Chnage the Text <b>now browsing by month</b>.',
		'id' => 'arc4',
		'std' => 'now browsing by month',
		'type' => 'text');
		
	$options[] = array(
		'name' => 'now browsing by year',
		'desc' => 'Chnage the Text <b>now browsing by year</b>.',
		'id' => 'arc5',
		'std' => 'now browsing by year',
		'type' => 'text');;	
		
	$options[] = array(
		'name' => 'now browsing by author',
		'desc' => 'Chnage the Text <b>now browsing by author</b>.',
		'id' => 'arc6',
		'std' => 'now browsing by author',
		'type' => 'text');
		
	$options[] = array(
		'name' => 'now browsing the general archives',
		'desc' => 'Chnage the Text <b>now browsing the general archives</b>.',
		'id' => 'arc7',
		'std' => 'now browsing the general archives',
		'type' => 'text');	
		

	return $options;
}

/*
 * This is an example of how to add custom scripts to the options panel.
 * This example shows/hides an option when a checkbox is clicked.
 */

add_action('optionsframework_custom_scripts', 'optionsframework_custom_scripts');

function optionsframework_custom_scripts() { ?>

<?php
}